Class: AbacatePay::Resources::Billings::Metadata

Inherits:
Resource
  • Object
show all
Defined in:
lib/abacate_pay/resources/billings/metadata.rb

Overview

Represents metadata for a billing resource in the AbacatePay system.

This class contains additional information related to a billing resource, such as fee, return URL, and completion URL.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(data) ⇒ Metadata

Creates a new Metadata instance

Parameters:

  • data (Hash)

    The metadata properties



23
24
25
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 23

def initialize(data)
  fill(data)
end

Instance Attribute Details

#completion_urlString?

Returns URL to redirect the user after successful payment.

Returns:

  • (String, nil)

    URL to redirect the user after successful payment



18
19
20
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 18

def completion_url
  @completion_url
end

#feeInteger?

Returns Fee associated with the billing.

Returns:

  • (Integer, nil)

    Fee associated with the billing



12
13
14
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 12

def fee
  @fee
end

#return_urlString?

Returns URL to redirect the user after payment is canceled or abandoned.

Returns:

  • (String, nil)

    URL to redirect the user after payment is canceled or abandoned



15
16
17
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 15

def return_url
  @return_url
end