Class: AbacatePay::Resources::Billings::Metadata
- Defined in:
- lib/abacate_pay/resources/billings/metadata.rb
Overview
Represents metadata for a billing resource in the AbacatePay system.
This class contains additional information related to a billing resource, such as fee, return URL, and completion URL.
Instance Attribute Summary collapse
-
#completion_url ⇒ String?
URL to redirect the user after successful payment.
-
#fee ⇒ Integer?
Fee associated with the billing.
-
#return_url ⇒ String?
URL to redirect the user after payment is canceled or abandoned.
Instance Method Summary collapse
-
#initialize(data) ⇒ Metadata
constructor
Creates a new Metadata instance.
Constructor Details
#initialize(data) ⇒ Metadata
Creates a new Metadata instance
23 24 25 |
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 23 def initialize(data) fill(data) end |
Instance Attribute Details
#completion_url ⇒ String?
Returns URL to redirect the user after successful payment.
18 19 20 |
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 18 def completion_url @completion_url end |
#fee ⇒ Integer?
Returns Fee associated with the billing.
12 13 14 |
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 12 def fee @fee end |
#return_url ⇒ String?
Returns URL to redirect the user after payment is canceled or abandoned.
15 16 17 |
# File 'lib/abacate_pay/resources/billings/metadata.rb', line 15 def return_url @return_url end |