Class: AbacatePay::Resources::Customers::Metadata
- Defined in:
- lib/abacate_pay/resources/customers/metadata.rb
Overview
Represents metadata for a customer in the AbacatePay system.
This class contains additional information about a customer, such as their name, contact details, and tax identification number.
Instance Attribute Summary collapse
-
#cellphone ⇒ String?
Customer's cellphone number.
-
#email ⇒ String?
Customer's email address.
-
#name ⇒ String?
Customer's name.
-
#tax_id ⇒ String?
Customer's tax identification number.
Instance Method Summary collapse
-
#initialize(data) ⇒ Metadata
constructor
Creates a new Metadata instance.
Constructor Details
#initialize(data) ⇒ Metadata
Creates a new Metadata instance
26 27 28 |
# File 'lib/abacate_pay/resources/customers/metadata.rb', line 26 def initialize(data) fill(data) end |
Instance Attribute Details
#cellphone ⇒ String?
Returns Customer's cellphone number.
15 16 17 |
# File 'lib/abacate_pay/resources/customers/metadata.rb', line 15 def cellphone @cellphone end |
#email ⇒ String?
Returns Customer's email address.
18 19 20 |
# File 'lib/abacate_pay/resources/customers/metadata.rb', line 18 def email @email end |
#name ⇒ String?
Returns Customer's name.
12 13 14 |
# File 'lib/abacate_pay/resources/customers/metadata.rb', line 12 def name @name end |
#tax_id ⇒ String?
Returns Customer's tax identification number.
21 22 23 |
# File 'lib/abacate_pay/resources/customers/metadata.rb', line 21 def tax_id @tax_id end |